summaryrefslogtreecommitdiffstats
path: root/hci/include
diff options
context:
space:
mode:
authorZach Johnson <zachoverflow@google.com>2015-03-04 14:47:00 -0800
committerAndre Eisenbach <eisenbach@google.com>2015-03-16 16:51:48 -0700
commitb55a8a62b23be97fcb3f2ba9f3c4cb03cfb59914 (patch)
treeb98c6a764929de273796b679d730f3065877dd8d /hci/include
parent04bb236d873005ccb5950cb8e8f1f348499e032e (diff)
downloadandroid_system_bt-b55a8a62b23be97fcb3f2ba9f3c4cb03cfb59914.tar.gz
android_system_bt-b55a8a62b23be97fcb3f2ba9f3c4cb03cfb59914.tar.bz2
android_system_bt-b55a8a62b23be97fcb3f2ba9f3c4cb03cfb59914.zip
Rejig hci upwards dispatch
Split events and acl data in hci dispatch, and dispatch events by event code Future code will now be able to dynamically tie into hci events, instead of relying on a hard coded routing.
Diffstat (limited to 'hci/include')
-rw-r--r--hci/include/hci_layer.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/hci/include/hci_layer.h b/hci/include/hci_layer.h
index 810e0b8a7..bdc468146 100644
--- a/hci/include/hci_layer.h
+++ b/hci/include/hci_layer.h
@@ -23,6 +23,7 @@
#include "allocator.h"
#include "bt_types.h"
#include "data_dispatcher.h"
+#include "fixed_queue.h"
#include "future.h"
#include "osi.h"
@@ -79,8 +80,11 @@ typedef struct hci_t {
// Do the postload sequence (call after the rest of the BT stack initializes).
void (*do_postload)(void);
- // Register with this data dispatcher to receive data flowing upward out of the HCI layer
- data_dispatcher_t *upward_dispatcher;
+ // Register with this data dispatcher to receive events flowing upward out of the HCI layer
+ data_dispatcher_t *event_dispatcher;
+
+ // Set the queue to receive ACL data in
+ void (*set_data_queue)(fixed_queue_t *queue);
// Send a command through the HCI layer
void (*transmit_command)(